@@ -1409,11 +1409,12 @@ game_props_callback (GSimpleAction *action,
     g_signal_connect (fast_moves_checkbutton, "clicked",
                       G_CALLBACK (set_fast_moves_callback), NULL);
 
-    pref_dialog_done = TRUE;
-  }
+    g_object_unref (G_OBJECT (builder_preferences));
 
-  gtk_window_set_transient_for (GTK_WINDOW (pref_dialog), GTK_WINDOW (app));
-  gtk_window_present (GTK_WINDOW (pref_dialog));
+    pref_dialog_done = TRUE;
+    gtk_window_set_transient_for (GTK_WINDOW (pref_dialog), GTK_WINDOW (app));
+  }
+  gtk_dialog_run (GTK_DIALOG (pref_dialog));
 }
 
 void
@@ -1595,6 +1596,7 @@ startup_cb (GApplication *application)
 
   hbox = GTK_WIDGET (gtk_builder_get_object (builder, "hbox"));
   draw_area = gtk_drawing_area_new ();
+  gtk_widget_set_size_request (draw_area, 300, 300);
   g_signal_connect (draw_area, "button-press-event",
                     G_CALLBACK (button_press_event), NULL);
   g_signal_connect (draw_area, "key-press-event",
@@ -1620,6 +1622,8 @@ startup_cb (GApplication *application)
   load_properties ();
 
   gtk_builder_connect_signals (builder, NULL);
+
+  g_object_unref (G_OBJECT (builder));
 }
 
 static void
